==> orchestra-api-4.4.0-sources.jar: org/ow2/orchestra/facade/runtime/impl/ActivityWithSingleChildInstanceImpl.java <==
/**
 * Copyright (C) 2008 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.runtime.impl;

import org.ow2.orchestra.facade.runtime.ActivityWithSingleChildInstance;
import org.ow2.orchestra.facade.uuid.ActivityInstanceUUID;


public abstract class ActivityWithSingleChildInstanceImpl extends ActivityInstanceImpl implements
  ActivityWithSingleChildInstance {

  private static final long serialVersionUID = -7848321760686526026L;

  protected ActivityInstanceUUID enclosedActivityUUID;

  public ActivityWithSingleChildInstanceImpl(final ActivityWithSingleChildInstance record) {
    super(record);
    enclosedActivityUUID = record.getEnclosedActivityUUID();
  }

  public ActivityInstanceUUID getEnclosedActivityUUID() {
    return enclosedActivityUUID;
  }

}

==> orchestra-api-4.9.0-sources.jar: org/ow2/orchestra/facade/runtime/impl/ActivityWithSingleChildInstanceImpl.java <==
/**
 * Copyright (C) 2008 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.runtime.impl;

import org.ow2.orchestra.facade.runtime.ActivityWithSingleChildInstance;
import org.ow2.orchestra.facade.uuid.ActivityInstanceUUID;

import javax.xml.bind.annotation.XmlElement;


public abstract class ActivityWithSingleChildInstanceImpl extends ActivityInstanceImpl implements
  ActivityWithSingleChildInstance {

  private static final long serialVersionUID = -7848321760686526026L;

  @XmlElement
  protected ActivityInstanceUUID enclosedActivityUUID;

  protected ActivityWithSingleChildInstanceImpl() {}

  public ActivityWithSingleChildInstanceImpl(final ActivityWithSingleChildInstance record) {
    super(record);
    enclosedActivityUUID = record.getEnclosedActivityUUID();
  }

  public ActivityInstanceUUID getEnclosedActivityUUID() {
    return enclosedActivityUUID;
  }

}
